@@ -1,8 +1,8 @@
 use strict;
 use warnings;
 package CPAN::Uploader;
-BEGIN {
-  $CPAN::Uploader::VERSION = '0.102150';
+{
+  $CPAN::Uploader::VERSION = '0.103001';
 }
 # ABSTRACT: upload things to the CPAN
 
@@ -14,7 +14,8 @@ use HTTP::Request::Common qw(POST);
 use HTTP::Status;
 use LWP::UserAgent;
 
-my $PAUSE_ADD_URI = 'http://pause.perl.org/pause/authenquery';
+my $UPLOAD_URI = $ENV{CPAN_UPLOADER_UPLOAD_URI}
+              || 'http://pause.perl.org/pause/authenquery';
 
 
 use Data::Dumper;
@@ -36,7 +37,7 @@ sub upload_file {
       "The following arguments would have been used to upload: \n"
       . '$self: ' . Dumper($self)
       . '$file: ' . Dumper($file)
-    ); 
+    );
   } else {
     $self->_upload($file);
   }
@@ -50,11 +51,14 @@ sub _ua_string {
   return "$class/$version";
 }
 
+sub uri { shift->{upload_uri} || $UPLOAD_URI }
+sub target { shift->{target} || 'PAUSE' }
+
 sub _upload {
   my $self = shift;
   my $file = shift;
 
-  $self->log("registering upload with PAUSE web server");
+  $self->log("registering upload with " . $self->target . " web server");
 
   my $agent = LWP::UserAgent->new;
   $agent->agent( $self->_ua_string );
@@ -62,8 +66,10 @@ sub _upload {
   $agent->env_proxy;
   $agent->proxy(http => $self->{http_proxy}) if $self->{http_proxy};
 
+  my $uri = $self->{upload_uri} || $UPLOAD_URI;
+
   my $request = POST(
-    $PAUSE_ADD_URI,
+    $uri,
     Content_Type => 'form-data',
     Content      => {
       HIDDENNAME                        => $self->{user},
@@ -89,7 +95,7 @@ sub _upload {
   );
 
   # Make the request to the PAUSE web server
-  $self->log("POSTing upload for $file");
+  $self->log("POSTing upload for $file to $uri");
   my $response = $agent->request($request);
 
   # So, how'd we do?
@@ -100,8 +106,8 @@ sub _upload {
   if ($response->is_error) {
     if ($response->code == RC_NOT_FOUND) {
       die "PAUSE's CGI for handling messages seems to have moved!\n",
-        "(HTTP response code of 404 from the PAUSE web server)\n",
-        "It used to be: ", $PAUSE_ADD_URI, "\n",
+        "(HTTP response code of 404 from the ", $self->target, " web server)\n",
+        "It used to be: ", $uri, "\n",
         "Please inform the maintainer of $self.\n";
     } else {
       die "request failed with error code ", $response->code,
@@ -115,7 +121,7 @@ sub _upload {
       "----- RESPONSE END -------\n"
     );
 
-    $self->log("PAUSE add message sent ok [" . $response->code . "]");
+    $self->log($self->target . " add message sent ok [" . $response->code . "]");
   }
 }
 
@@ -152,7 +158,7 @@ sub read_config_file {
     Carp::croak "multiple enties for $k" if $from_file{$k};
     $from_file{$k} = $v;
   }
-  
+
   return \%from_file;
 }
 
@@ -180,7 +186,7 @@ CPAN::Uploader - upload things to the CPAN
 
 =head1 VERSION
 
-version 0.102150
+version 0.103001
 
 =head1 METHODS
 
@@ -195,7 +201,8 @@ Valid arguments are:
   user       - (required) your CPAN / PAUSE id
   password   - (required) your CPAN / PAUSE password
   subdir     - the directory (under your home directory) to upload to
-  http_proxy - url of the http proxy to use 
+  http_proxy - uri of the http proxy to use
+  upload_uri - uri of the upload handler; usually the default (PAUSE) is right
   debug      - if set to true, spew lots more debugging output
 
 This method attempts to actually upload the named file to the CPAN.  It will
@@ -233,11 +240,6 @@ needed.
 This method behaves like C<L</log>>, but only logs the message if the
 CPAN::Uploader is in debug mode.
 
-=head1 WARNING
-
-  This is really, really not well tested or used yet.  Give it a few weeks, at
-  least.  -- rjbs, 2008-06-06
-
 =head1 ORIGIN
 
 This code is mostly derived from C<cpan-upload-http> by Brad Fitzpatrick, which
@@ -251,7 +253,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
